import { Link } from "@/i18n";
import { useGlobalStore } from "@/stores";
import clsx from "clsx";
import { useTranslations } from "next-intl";
import { FC, ReactNode } from "react";
import HeaderTitle from "./HerderTitle";
import styles from "./style.module.scss";
/**
 * @description HeaderProps
 * @param {boolean} headerPlaceholder 是否展示展位元素
 * @param {() => ReactNode} headerRender 自定义渲染
 */
export interface HeaderProps {
    headerPlaceholder?: boolean;
    headerRender?: () => ReactNode;
    menuHandler?: () => void;
}

const cs = clsx(["iconfont icon-gengduo", styles.menu]);
const DefaultHeader: FC<HeaderProps> = (props) => {
    const { menuHandler } = props;
    const t = useTranslations("Header");
    const state = useGlobalStore();

    return (
        <div className={styles.headerMain}>
            <div className={styles.headerLeft} onClick={menuHandler}>
                {/*<div className={cs}></div>*/}
            </div>
            <HeaderTitle />
            <div className={styles.headerRight}>
                <div className={styles.right}>
                    {state.userInfo ? (
                        <>
                            <Link href={"/profile"}>
                                <div className={"flex items-center text-[0.12rem]"}>
                                    <i className={"iconfont icon-yonghu mr-[0.03rem]"}></i>
                                    <span>0.00</span>
                                </div>
                            </Link>

                            <Link href={"/deposit"} className={styles.rightActive}>
                                {t("deposit")}
                            </Link>
                        </>
                    ) : (
                        <>
                            <Link href={"/login?redirect=/withdraw"}>{t("login")}</Link>
                            <Link href={"/login?redirect=/withdraw"} className={styles.rightActive}>
                                {t("register")}
                            </Link>
                        </>
                    )}
                </div>
            </div>
        </div>
    );
};

const Header: FC<HeaderProps> = (props) => {
    const { headerPlaceholder = true, headerRender, ...other } = props;
    const cs = clsx({
        [styles.placeholder]: headerPlaceholder,
    });
    return (
        <div className={cs}>
            <div className={styles.headerWrap}>
                {headerRender ? headerRender() : <DefaultHeader {...other} />}
            </div>
        </div>
    );
};
export default Header;
