"use client";
import Footer, { FooterProps } from "@/components/Footer";
import Header, { HeaderProps } from "@/components/Header";
import Sidebar from "@/components/Layout/Sidebar";
import { FC, PropsWithChildren, useEffect, useRef, useState } from "react";
import { Swiper, SwiperClass, SwiperSlide } from "swiper/react";
import styles from "./style.module.scss";
type Props = FooterProps & HeaderProps;
const Layout: FC<PropsWithChildren<Props>> = (props) => {
    const { children } = props;

    const swiperRef = useRef<SwiperClass>();
    const isOpen = useRef<boolean>(false);
    const homeContainerRef = useRef<HTMLDivElement>(null);
    const barRef = useRef<HTMLDivElement>(null);

    const [mounted, setMounted] = useState(false);

    useEffect(() => {
      setMounted(true)
    }, []);

    const startHandler = () => {
        homeContainerRef.current?.classList.add(styles.containerMask);
        barRef.current?.classList.add(styles.cross);
        isOpen.current = true;
    };
    const endHandler = () => {
        homeContainerRef.current?.classList.remove(styles.containerMask);
        barRef.current?.classList.remove(styles.cross);
        isOpen.current = false;
    };

    const openSliderHandler = () => {
        if (isOpen.current) {
            swiperRef.current?.slideNext();
        } else {
            swiperRef.current?.slidePrev();
        }
    };

    return (
        <Swiper
            initialSlide={1}
            resistanceRatio={0}
            slidesPerView={"auto"}
            onSlidePrevTransitionStart={startHandler}
            onSlideNextTransitionEnd={endHandler}
            slideToClickedSlide
            onSwiper={(swiper) => {
                swiperRef.current = swiper;
            }}
            allowTouchMove={false}
        > 
            <SwiperSlide style={{ width: `${!mounted ? '0' : '70%'}`,overflow:'hidden' }} className={"mx-w-[2.2222rem] bg-[rgb(31,31,31)]"}>
              <section className="relative h-[100vh]">
                  <Sidebar></Sidebar>
              </section>
            </SwiperSlide>
            
           

            <SwiperSlide style={{ width: "100%" }}>
                <div className="relative h-[100vh]" ref={homeContainerRef}>
                    <div
                        className={`absolute left-[0.1rem] top-[0.15rem] z-40 text-[#fff]`}
                        ref={barRef}
                        onClick={openSliderHandler}
                    >
                        <div className={styles.bar}></div>
                        <div className={styles.bar} style={{ width: "0.1389rem" }}></div>
                        <div className={styles.bar}></div>
                    </div>
                    <Header {...props}></Header>
                    <main className={styles.main} id="maincontainer">
                        {children}
                    </main>
                    <Footer {...props}></Footer>
                </div>
            </SwiperSlide>
        </Swiper>
    );
};

export default Layout;
